export default {
    "message": "Cannot use 'await' as identifier inside an async function",
    "column": 28,
    "index": 27,
    "lineNumber": 1
}
